(this.webpackJsonpstreamlit_component_template=this.webpackJsonpstreamlit_component_template||[]).push([[0],{24:function(e,t,a){e.exports=a(37)},37:function(e,t,a){"use strict";a.r(t);var r=a(8),n=a.n(r),c=a(22),i=a.n(c),o=a(5),l=a(6),d=a(0),s=a(1),p=a(2),m=a(20),u=a(14),b=a(16),h={card:{marginTop:4,border:"1.5px solid",borderRadius:4,padding:12,cursor:"pointer",borderColor:"rgba(0, 0, 0, 0.12)",fontFamily:'"Roboto", "Helvetica", "Arial", sans-serif',display:"flex"},highlightCard:{borderColor:"#2196f3"},cardHeaderIcon:{marginRight:12,height:24},cardHeaderId:{marginRight:12,color:"rgba(0, 0, 0, 0.54)",minWidth:20,display:"inline-block",textTransform:"uppercase"},cardHeaderContent:{display:"inline-block",color:"rgba(0, 0, 0, 0.54)",width:"100%",whiteSpace:"nowrap",overflow:"hidden",textOverflow:"ellipsis"},cardContent:{marginTop:4,borderRadius:4,padding:12,backgroundColor:"rgb(14, 17, 23)",color:"#00f900"},truncate:{width:"100%",whiteSpace:"nowrap",overflow:"hidden",textOverflow:"ellipsis"}},g=function(e){Object(s.a)(a,e);var t=Object(p.a)(a);function a(){var e;Object(d.a)(this,a);for(var r=arguments.length,c=new Array(r),i=0;i<r;i++)c[i]=arguments[i];return(e=t.call.apply(t,[this].concat(c))).state={},e.clickCard=function(t){return function(){e.state.visibleItem===t?e.setState({visibleItem:void 0}):e.setState({visibleItem:t})}},e.getIcon=function(e){switch(e){case"spinner":return n.a.createElement(u.a,{icon:b.d,spin:!0,color:"#2196f3",style:h.cardHeaderIcon});case"circle-check":return n.a.createElement(u.a,{icon:b.a,color:"#4caf50",style:h.cardHeaderIcon});case"triangle-exclaimation":return n.a.createElement(u.a,{icon:b.b,color:"#ab003c",style:h.cardHeaderIcon});case"hourglass":return n.a.createElement(u.a,{icon:b.c,color:"#2196f3",style:h.cardHeaderIcon});default:return}},e.render=function(){var t,a=e.props.args.list,r=[],c=Object(l.a)(a);try{for(c.s();!(t=c.n()).done;){var i=t.value,d=Object(o.a)({},h.card);e.state.visibleItem===i.id&&Object.assign(d,h.highlightCard),r.push(n.a.createElement("div",{key:i.id,style:d,onClick:e.clickCard(i.id)},e.getIcon(i.icon),n.a.createElement("span",{style:h.cardHeaderId},i.id),n.a.createElement("span",{style:h.cardHeaderContent},i.name))),e.state.visibleItem===i.id&&r.push(n.a.createElement("div",{key:"content",style:h.cardContent,dangerouslySetInnerHTML:{__html:i.value}}))}}catch(s){c.e(s)}finally{c.f()}return n.a.createElement("div",{style:{paddingBottom:4}},r)},e}return a}(m.a),f=Object(m.b)(g);i.a.render(n.a.createElement(n.a.StrictMode,null,n.a.createElement(f,null)),document.getElementById("root"))}},[[24,1,2]]]);
//# sourceMappingURL=main.f63112e9.chunk.js.map